#!/bin/sh

set -e

if echo "$CI_COMMIT_TAG" | grep '^heptapod-'; then
    TARBALL=$(echo -n $CI_COMMIT_TAG | sed s/heptapod/heptapod-rails/g)
    # pulling on the current branch and the two main heptapod ones
    # so that `hg archive` should see the tag (very unlikely the tagging
    # changeset would be elsewhere, not worth pulling the whole repo)
    # using `hg log` instead of `hg branch` to avoid newline for safety
    hg pull -r heptapod -r heptapod-stable -r `hg log -r. -T "{branch}"` || /bin/true
    SUBDIR=public
else
    TARBALL=heptapod-rails-$(hg log -r. -T "{node}")
    SUBDIR=public/intermediate
fi

# it's nicer for console output to add the extension right away
TARBALL=${TARBALL}.tar.gz

TARBALL_PATH=/tmp/${TARBALL}

echo "Generating ${TARBALL}"
hg archive -t tgz ${TARBALL_PATH}
echo "Generating SHA-256 checksum"
sha256sum ${TARBALL_PATH} > ${TARBALL_PATH}.sha256sum
cat ${TARBALL_PATH}.sha256sum

if [ -n "$HEPTAPOD_TARBALL_UPLOAD_KEY" ]; then
    `dirname $0`/heptapod-sftp-push \
                upload.heptapod.net \
                "$HEPTAPOD_TARBALL_UPLOAD_KEY" \
                "$TARBALL_PATH" \
                "${SUBDIR}/src"
fi
